#include <cassert>

#include <vector>
using std::vector;

#include <queue>
using std::queue;

#include <iostream>
using std::cout;
using std::endl;
using std::ostream;

class step
{
public:
	int x,y; // x-y coordinates
	char d; // step direction: n,s,e,w
private:
	void move(char d)
	{
		if (d == 'n') ++y;
		else if (d == 's') --y;
		else if (d == 'e') ++x;
		else if (d == 'w') --x;
		else assert(false);
	}
public:
	// constructors
	step(char d_) : x(0), y(0), d(d_) { move(d); };
	step(const step &last_step, char d_) : x(last_step.x), y(last_step.y), d(d_) { move(d); }
	
	// determine if two steps arrive at the same location
	friend bool operator==(const step &s1, const step &s2) { return s1.x == s2.x and s1.y == s2.y; }
};

class saw
{
private:
	// storage: the saw is represented as a vector of steps
	vector<step> path;
public:
	// constructor
	saw(char d) : path() { path.push_back(step(d)); }

	// return the length of the walk
	size_t length(void) const { return path.size(); }

	// return the direction of the last step of the walk
	char last_direction(void) const { return (length() > 0 ? path[length()-1].d : ' '); }

	// return the last step of the walk
	const step& last_step(void) const { return path[length()-1]; }

	// determine whether a step in direction d would cause the walk to intersect itself
	bool is_allowed(char d)
	{
		step next_step(last_step(),d);
		if (next_step.x == 0 and next_step.y == 0)
			return false;
		for (size_t i = 0; i < length(); ++i)
			if (path[i] == next_step)
				return false;
		return true;
	}

	// create a new walk by adding a single step in direction d
	friend saw operator+(const saw &walk, char d)
	{
		saw walk2(walk);
		walk2.path.push_back(step(walk2.last_step(),d));
		return walk2;
	}

	// dump the sequence of steps to a stream
	friend ostream& operator<<(ostream &os, const saw &walk)
	{
		for (size_t i = 0; i < walk.length(); ++i)
			os << walk.path[i].d;
		return os;
	}
};

const size_t N = 14;
queue<saw> Q;
vector<size_t> num(N);

int main()
{
	// initialize the counter
	for (size_t i = 0; i < N; ++i)
		num[i] = 0.0;

	// push a single north-directed, one-step walk onto the back of the queue
	Q.push(saw('n'));
	num[0] = 1;
	
	// begin the main loop
	while (!Q.empty())
	{
		// pop a walk off the front of the queue
		saw walk = Q.front();
		Q.pop();
		const size_t l = walk.length();
		if (l < N)
		{
			const char dir[] = "nswe";
			const char opp[] = "snew";
			for (size_t i = 0; i < 4; ++i)
				if (walk.last_direction() != opp[i] and walk.is_allowed(dir[i]))
				{
					// push a walk onto the back of the queue
					Q.push(walk + dir[i]);
					
					// the new walk pushed onto the queue is accessed via Q.back()
					assert( Q.back().length() == l+1 );
					
					// the direction of the last step is Q.back().last_direction
					assert( Q.back().last_direction() == dir[i] );
					
					// the last step itself is Q.back().last_step()
					++num[l];
				}
		}
	}
	
	// print out the results
	for (size_t l = 0; l < N; ++l)
		cout << l+1 << "\t" << 4*num[l] << endl;
	return 0;
}

